JoinedValuesPlan

Struct JoinedValuesPlan 

pub struct JoinedValuesPlan<L, R, LK, LV, RK, RV, JK, OV, FL, FR, F>
where L: MapQuery<Key = LK, Value = LV>, R: MapQuery<Key = RK, Value = RV>, LK: Hash + Eq + CellValue, LV: CellValue, RK: Hash + Eq + CellValue, RV: CellValue, JK: Hash + Eq + CellValue, OV: CellValue, FL: Fn(&LK, &LV) -> JK + Send + Sync + 'static, FR: RightJoinKey<RK, RV, JK>, F: Fn(&LK, &LV, &[(RK, RV)]) -> OV + Send + Sync + 'static,
{ /* private fields */ }
A left join whose output is projected directly from the indexed matches.

Implementations

Source

impl<L, R1, LK, LV, RK1, RV1, JK1, MV, FL1, FR1, FM1> JoinedValuesPlan<L, R1, LK, LV, RK1, RV1, JK1, MV, FL1, FR1, FM1>
where L: MapQuery<Key = LK, Value = LV> + PreservesMapKey<LK>, R1: MapQuery<Key = RK1, Value = RV1>, LK: Hash + Eq + CellValue, LV: CellValue, RK1: Hash + Eq + CellValue, RV1: CellValue, JK1: Hash + Eq + CellValue, MV: CellValue, FL1: Fn(&LK, &LV) -> JK1 + Send + Sync + 'static, FR1: RightJoinKey<RK1, RV1, JK1>, FM1: Fn(&LK, &LV, &[(RK1, RV1)]) -> MV + Send + Sync + 'static,

pub fn left_join_by<R2, RK2, RV2, JK2, FL2, FR2>( self, right: R2, left_key: FL2, right_key: FR2, ) -> TwoLeftJoinPlan<L, R1, R2, LK, LV, RK1, RV1, JK1, MV, RK2, RV2, JK2, FL1, FR1, DirectJoinProjection<FM1>, FL2, RequiredRightKey<FR2>>
where R2: MapQuery<Key = RK2, Value = RV2>, RK2: Hash + Eq + CellValue, RV2: CellValue, JK2: Hash + Eq + CellValue, FL2: Fn(&LK, &MV) -> JK2 + Send + Sync + 'static, FR2: Fn(&RK2, &RV2) -> JK2 + Send + Sync + 'static,

Extend a direct joined projection with a coordinated second left join.